#!/usr/local/bin/bash

# Startskript fr Thin Clients


# ***  Vorgabewerte, die eventuell angepat werden mssen  ***

# Die IP-Adresse des zu verwendenden X-Hosts. Wenn Sie hier nichts angeben,
# wird per Broadcast nach einem X-Host gesucht. Es wird dann der X-Host
# verwendet, der als erstes auf den Broadcast antwortet.
XHOST=

# Die IP-Adresse des NFS-Servers, von dem das Root-Dateisystem gemountet wurde.
# Dies wird z.B. weiter unten fr den Zeitabgleich und das Spool-Verzeichnis
# verwendet und sollte normalerweise automatisch ermittelt werden knnen.
NFSSERVER=`mount -t nfs  |  grep ' on / '  |  cut -d: -f1`

# ***  Ende der Vorgabewerte - ab hier brauchen normalerweise keine  ***
# ***  nderungen mehr vorgenommen zu werden                         ***


# Wenn als erster Parameter nicht "start" bergeben wird, brechen wir ab:
if [ "$1" != "start" ]
   then exit
fi

# Information fr den Anwender ausgeben:
echo -e "\n\n    * * *   S t a r t s k r i p t   f  r   T h i n   C l i e n t s   * * *\n"
echo "Hostname:  `hostname` \
      IP:  `ifconfig  |  grep inet  |  head -n1  |  cut -d\  -f2` \
      System:  `uname -s`/`uname -m`"

# Synchronisiere die Uhrzeit mit dem NFS-Server:
echo -e "\nSynchronisiere die Uhrzeit mit $NFSSERVER..."
/usr/sbin/ntpdate "$NFSSERVER"  > /dev/null
/bin/sleep 2

# Kernel-Module laden
echo -e "\nZustzliche Kernel-Module werden geladen..."
case `hostname -s` in
  term*)  /sbin/kldload snd_pcm snd_es137x  ;;
esac

# Den eSound-Server starten
echo -e "\nStarte den eSound-Server..."
/usr/bin/nice -n -20 /usr/local/bin/esd -tcp -public -nobeeps -trust &

# Die Lautstrke fr die Soundausgabe wird auf 100% eingestellt. ndert eine
# eSound-Anwendung auf dem X-Host die Lautstrke, wird dies direkt von der
# Anwendung verarbeitet, nicht vom Mixer-Gert auf dem Thin Client. Es ist
# daher sinnvoll, hier einen sinnvollen Wert einzustellen, den Rest erledigt
# ohnehin die Anwendung auf dem X-Host.
/usr/sbin/mixer vol 100 pcm 100 >/dev/null 2>&1


# Bei Bedarf den Drucker-Host starten. Ein Bedarf wird immer dann angenommen,
# wenn die Datei /etc/Printers/printcap.`hostname -s` existiert.
if [ -f /etc/Printers/printcap.`hostname -s` ]
   then echo -e "\nStarte den Drucker-Host auf diesem Thin Client..."

	# Rechnerspezifische printcap kopieren:
	cp -p /etc/Printers/printcap.`hostname -s` /etc/printcap

	# Rechnerspezifischen lpfilter kopieren. Da dieser nicht zwingend
	# bentigt wird, an dieser Stelle keine Fehlermeldungen ausgeben.
        cp -p /etc/Printers/lpfilter.`hostname -s` /etc/lpfilter  2>/dev/null

	# Sorge dafr, da die Logdatei existiert:
	touch /var/log/lpd

	# Sofern auf dem NFS-Server ein Spooler-Verzeichnis fr diesen Thin
	# Client angelegt wurde, mounten wir es jetzt. Auch hier keine Fehler-
	# meldungen ausgeben, da das Verzeichnis optional ist.
	mount_nfs  \
		"$NFSSERVER":/opt/Software/ThinClient/Spooler/`hostname -s`  \
		/var/spool/lpd  2>/dev/null &

	# Abschlieend kann der LPD gestartet werden:
        /usr/sbin/lpd &
fi


# Ermittele den Namen der XFree-Konfigurationsdatei. Diese wird unter /etc/X11
# erwartet und mu als Dateiname den Hostnamen des Thin Clients tragen.
XF86CONFIG=/etc/X11/"`hostname -s`"

if [ ! -f "$XF86CONFIG" ]
   then echo -e "\nDie XFree-Konfigurationsdatei $XF86CONFIG existiert nicht!\n"
	exit 1
fi

# Gewnschten Modus festlegen und Info ber den X-Server ausgeben:
if [ -z "$XHOST" ]
  then MODE=BROAD
       echo -e "\nStarte den XFree86-Server:  Broadcast,  Konfig-Datei=$XF86CONFIG"
  else MODE=QUERY
       echo -e "\nStarte den XFree86-Server:  X-Host=$XHOST,  Konfig-Datei=$XF86CONFIG"
fi

# Den X-Server starten:

echo -e "\nENTER          =  Neuen X-Server starten"
echo      "STRG+ALT+ENTF  =  Thin Client neu booten"
echo      "STRG+C         =  X-Server beenden und Konsole starten"
echo -en "\n===>   "

while /usr/bin/true
do
  case "$MODE" in
    BROAD) /usr/X11R6/bin/X -xf86config "$XF86CONFIG" -broadcast &>/dev/null &
           ;;
    QUERY) /usr/X11R6/bin/X -xf86config "$XF86CONFIG" -query "$XHOST" &>/dev/null &
           ;;
  esac
  read -s
done  
